==> haskell-vector-instances-3.4.3-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-8dfeU1lfQX2AOwspVtc3sP
key:                  vector-instances-3.4.3-8dfeU1lfQX2AOwspVtc3sP
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  e32a08b1bba8b9ac5867c56e02c8704f
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-8dfeU1lfQX2AOwspVtc3sP
depends:
    base-4.17.2.1 comonad-5.0.9-BwSgGbEK8HU1NmS9v2nuKD
    hashable-1.4.4.0-AFqmlTE0BBaCoTGEV5znl2
    keys-3.12.4-3mpnJD955x8LNxoUmvepgB
    pointed-5.0.5-9b1wq4iLy1b2Ivm8FUdXg
    semigroupoids-6.0.1-FU0ghIuryZz6PWAGcEgYt0
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4.3-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-7O6UtF3in2J5fvJtfkVShc
key:                  vector-instances-3.4.3-7O6UtF3in2J5fvJtfkVShc
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  64409543c070ab5daafc8d8b6437cb95
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-7O6UtF3in2J5fvJtfkVShc
depends:
    base-4.17.2.1 comonad-5.0.9-Fgzi2ELWZ8DIst9tSOthfF
    hashable-1.4.4.0-92QHxum7zjW25fH5Mdbvto
    keys-3.12.4-9l1JLaxgm2tCADZWDXqCDX
    pointed-5.0.5-G2mwNv0C2Dp1fUdwKjpaN3
    semigroupoids-6.0.1-FLhvzqLeqBBAf5JZ5RJbkv
    vector-0.13.2.0-LTUcBi4LXgv7CSERMHHzQp

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
